@@ -1,5 +1,7 @@
 require("tsfa")
 
+if (require("CDNmoney")) {
+
 data("CanadianMoneyData.asof.6Feb2004", package="CDNmoney")
 
 #require("dse1")
@@ -175,3 +177,4 @@ cat("tests completed.\n")
 
 
 if (! all.ok) stop("some tests FAILED")
+} else cat("CDNmoney data not available. Tests skipped.\n")
